@@ -14,3 +14,13 @@ class ConfigGithub(Config):
     token = ParamCreator.create_str(
         help_string="What is your github token?",
     )
+
+
+class ConfigOutput(Config):
+    """
+    Parameters to control output
+    """
+    verbose = ParamCreator.create_bool(
+        help_string="be verbose?",
+        default=False,
+    )
